@@ -2,14 +2,14 @@
 
 set -e
 
-# called by uscan with '--upstream-version' <version> <file>
-echo "version $2"
+url="http://atinject.googlecode.com/files/javax.inject.zip"
 package=`dpkg-parsechangelog | sed -n 's/^Source: //p'`
 version=`dpkg-parsechangelog | sed -n 's/^Version: \(.*\)-.*/\1/p'`
-tarball=$3
+tarball="javax.inject.zip"
 TAR=${package}_${version}.orig.tar.gz
 DIR=${package}-${version}.orig
 
+wget $url
 unzip $tarball -d $DIR
 unzip $DIR/javax.inject-src.zip -d $DIR
 
